/*
 * Copyright (c) 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.

 */

package com.google.api.gwt.services.calendar.shared;

import com.google.api.gwt.shared.AuthScope;
import com.google.web.bindery.autobean.shared.AutoBean.PropertyName;
import com.google.web.bindery.requestfactory.shared.JsonRpcContent;
import com.google.web.bindery.requestfactory.shared.JsonRpcService;
import com.google.web.bindery.requestfactory.shared.JsonRpcWireName;
import com.google.web.bindery.requestfactory.shared.Request;
import com.google.web.bindery.requestfactory.shared.RequestContext;
import com.google.web.bindery.requestfactory.shared.RequestFactory;

/**
 * Service definition for Calendar (v3).
 *
 * <p>
 * Lets you manipulate events and other calendar data.
 * </p>
 *
 * <p>
 * For more information about this service, see the
 * <a href="http://code.google.com/apis/calendar/v3/using.html" target="_blank">API Documentation</a>
 * </p>
 *
 * @author Google, Inc.
 */
public interface Calendar extends RequestFactory {
  /** Available authentiation scopes for use with this service. */
  public enum CalendarAuthScope implements AuthScope {

    /** Manage your calendars */
    CALENDAR("https://www.googleapis.com/auth/calendar"),

    /** View your calendars */
    CALENDAR_READONLY("https://www.googleapis.com/auth/calendar.readonly"),
    ;
    private final String scope;
    private CalendarAuthScope(String scope) {
      this.scope = scope;
    }

    /** The String value of this scope. */
    @Override
    public String getScope() {
      return scope;
    }
  }

  /** Returns the {@link #FreebusyContext} context. */
  FreebusyContext freebusy();

  /**
   * The {@link RequestContext} used to call methods on the "freebusy" collection.
   */
  @JsonRpcService
  public interface FreebusyContext extends RequestContext {

    /**
     * Returns free/busy information for a set of calendars.
     *
     *
     * @param content Request body content.
     */
    QueryRequest query(@JsonRpcContent com.google.api.gwt.services.calendar.shared.model.FreeBusyRequest content);

    /**
     * Request object to call the "calendar.freebusy.query" method.
     */
    @JsonRpcWireName(value="calendar.freebusy.query", version="v3")
    public interface QueryRequest extends Request<com.google.api.gwt.services.calendar.shared.model.FreeBusyResponse> {
    }
  }
  /** Returns the {@link #SettingsContext} context. */
  SettingsContext settings();

  /**
   * The {@link RequestContext} used to call methods on the "settings" collection.
   */
  @JsonRpcService
  public interface SettingsContext extends RequestContext {

    /**
     * Returns all user settings for the authenticated user.
     *
     *
     */
    ListRequest list();

    /**
     * Request object to call the "calendar.settings.list" method.
     */
    @JsonRpcWireName(value="calendar.settings.list", version="v3")
    public interface ListRequest extends Request<com.google.api.gwt.services.calendar.shared.model.Settings> {
    }
    /**
     * Returns a single user setting.
     *
     *
     * @param setting Name of the user setting.
     */
    GetRequest get(@PropertyName("setting") String setting);

    /**
     * Request object to call the "calendar.settings.get" method.
     */
    @JsonRpcWireName(value="calendar.settings.get", version="v3")
    public interface GetRequest extends Request<com.google.api.gwt.services.calendar.shared.model.Setting> {

      /** Name of the user setting. */
      @PropertyName("setting")
      GetRequest setSetting(@PropertyName("setting") String setting);
    }
  }
  /** Returns the {@link #CalendarListContext} context. */
  CalendarListContext calendarList();

  /**
   * The {@link RequestContext} used to call methods on the "calendarList" collection.
   */
  @JsonRpcService
  public interface CalendarListContext extends RequestContext {

    /**
     * Adds an entry to the user's calendar list.
     *
     *
     * @param content Request body content.
     */
    InsertRequest insert(@JsonRpcContent com.google.api.gwt.services.calendar.shared.model.CalendarListEntry content);

    /**
     * Request object to call the "calendar.calendarList.insert" method.
     */
    @JsonRpcWireName(value="calendar.calendarList.insert", version="v3")
    public interface InsertRequest extends Request<com.google.api.gwt.services.calendar.shared.model.CalendarListEntry> {
    }
    /**
     * Returns an entry on the user's calendar list.
     *
     *
     * @param calendarId Calendar identifier.
     */
    GetRequest get(@PropertyName("calendarId") String calendarId);

    /**
     * Request object to call the "calendar.calendarList.get" method.
     */
    @JsonRpcWireName(value="calendar.calendarList.get", version="v3")
    public interface GetRequest extends Request<com.google.api.gwt.services.calendar.shared.model.CalendarListEntry> {

      /** Calendar identifier. */
      @PropertyName("calendarId")
      GetRequest setCalendarId(@PropertyName("calendarId") String calendarId);
    }
    /**
     * Returns entries on the user's calendar list.
     *
     *
     */
    ListRequest list();

    /**
     * Request object to call the "calendar.calendarList.list" method.
     */
    @JsonRpcWireName(value="calendar.calendarList.list", version="v3")
    public interface ListRequest extends Request<com.google.api.gwt.services.calendar.shared.model.CalendarList> {

      /** Token specifying which result page to return. Optional. */
      @PropertyName("pageToken")
      ListRequest setPageToken(@PropertyName("pageToken") String pageToken);

      /** Whether to show hidden entries. Optional. The default is False. */
      @PropertyName("showHidden")
      ListRequest setShowHidden(@PropertyName("showHidden") Boolean showHidden);

      /** Maximum number of entries returned on one result page. Optional. */
      @PropertyName("maxResults")
      ListRequest setMaxResults(@PropertyName("maxResults") Integer maxResults);

      /**
     * The minimum access role for the user in the returned entires. Optional. The default is no
     * restriction.
     */
      @PropertyName("minAccessRole")
      ListRequest setMinAccessRole(@PropertyName("minAccessRole") ListRequest.MinAccessRole minAccessRole);

      /** Possible values for {@link #setMinAccessRole(MinAccessRole)}. */
      public enum MinAccessRole {

        /** The user can read free/busy information. */
        @PropertyName("freeBusyReader") FREEBUSYREADER,
        /** The user can read and modify events and access control lists. */
        @PropertyName("owner") OWNER,
        /** The user can read events that are not private. */
        @PropertyName("reader") READER,
        /** The user can read and modify events. */
        @PropertyName("writer") WRITER,
        ;
      }}
    /**
     * Updates an entry on the user's calendar list.
     *
     *
     * @param calendarId Calendar identifier.
     * @param content Request body content.
     */
    UpdateRequest update(@PropertyName("calendarId") String calendarId, @JsonRpcContent com.google.api.gwt.services.calendar.shared.model.CalendarListEntry content);

    /**
     * Request object to call the "calendar.calendarList.update" method.
     */
    @JsonRpcWireName(value="calendar.calendarList.update", version="v3")
    public interface UpdateRequest extends Request<com.google.api.gwt.services.calendar.shared.model.CalendarListEntry> {

      /** Calendar identifier. */
      @PropertyName("calendarId")
      UpdateRequest setCalendarId(@PropertyName("calendarId") String calendarId);
    }
    /**
     * Updates an entry on the user's calendar list. This method supports patch semantics.
     *
     *
     * @param calendarId Calendar identifier.
     * @param content Request body content.
     */
    PatchRequest patch(@PropertyName("calendarId") String calendarId, @JsonRpcContent com.google.api.gwt.services.calendar.shared.model.CalendarListEntry content);

    /**
     * Request object to call the "calendar.calendarList.patch" method.
     */
    @JsonRpcWireName(value="calendar.calendarList.patch", version="v3")
    public interface PatchRequest extends Request<com.google.api.gwt.services.calendar.shared.model.CalendarListEntry> {

      /** Calendar identifier. */
      @PropertyName("calendarId")
      PatchRequest setCalendarId(@PropertyName("calendarId") String calendarId);
    }
    /**
     * Deletes an entry on the user's calendar list.
     *
     *
     * @param calendarId Calendar identifier.
     */
    DeleteRequest delete(@PropertyName("calendarId") String calendarId);

    /**
     * Request object to call the "calendar.calendarList.delete" method.
     */
    @JsonRpcWireName(value="calendar.calendarList.delete", version="v3")
    public interface DeleteRequest extends Request<Void> {

      /** Calendar identifier. */
      @PropertyName("calendarId")
      DeleteRequest setCalendarId(@PropertyName("calendarId") String calendarId);
    }
  }
  /** Returns the {@link #CalendarsContext} context. */
  CalendarsContext calendars();

  /**
   * The {@link RequestContext} used to call methods on the "calendars" collection.
   */
  @JsonRpcService
  public interface CalendarsContext extends RequestContext {

    /**
     * Creates a secondary calendar.
     *
     *
     * @param content Request body content.
     */
    InsertRequest insert(@JsonRpcContent com.google.api.gwt.services.calendar.shared.model.Calendar content);

    /**
     * Request object to call the "calendar.calendars.insert" method.
     */
    @JsonRpcWireName(value="calendar.calendars.insert", version="v3")
    public interface InsertRequest extends Request<com.google.api.gwt.services.calendar.shared.model.Calendar> {
    }
    /**
     * Returns metadata for a calendar.
     *
     *
     * @param calendarId Calendar identifier.
     */
    GetRequest get(@PropertyName("calendarId") String calendarId);

    /**
     * Request object to call the "calendar.calendars.get" method.
     */
    @JsonRpcWireName(value="calendar.calendars.get", version="v3")
    public interface GetRequest extends Request<com.google.api.gwt.services.calendar.shared.model.Calendar> {

      /** Calendar identifier. */
      @PropertyName("calendarId")
      GetRequest setCalendarId(@PropertyName("calendarId") String calendarId);
    }
    /**
     * Clears a primary calendar. This operation deletes all data associated with the primary calendar
     * of an account and cannot be undone.
     *
     *
     * @param calendarId Calendar identifier.
     */
    ClearRequest clear(@PropertyName("calendarId") String calendarId);

    /**
     * Request object to call the "calendar.calendars.clear" method.
     */
    @JsonRpcWireName(value="calendar.calendars.clear", version="v3")
    public interface ClearRequest extends Request<Void> {

      /** Calendar identifier. */
      @PropertyName("calendarId")
      ClearRequest setCalendarId(@PropertyName("calendarId") String calendarId);
    }
    /**
     * Updates metadata for a calendar.
     *
     *
     * @param calendarId Calendar identifier.
     * @param content Request body content.
     */
    UpdateRequest update(@PropertyName("calendarId") String calendarId, @JsonRpcContent com.google.api.gwt.services.calendar.shared.model.Calendar content);

    /**
     * Request object to call the "calendar.calendars.update" method.
     */
    @JsonRpcWireName(value="calendar.calendars.update", version="v3")
    public interface UpdateRequest extends Request<com.google.api.gwt.services.calendar.shared.model.Calendar> {

      /** Calendar identifier. */
      @PropertyName("calendarId")
      UpdateRequest setCalendarId(@PropertyName("calendarId") String calendarId);
    }
    /**
     * Updates metadata for a calendar. This method supports patch semantics.
     *
     *
     * @param calendarId Calendar identifier.
     * @param content Request body content.
     */
    PatchRequest patch(@PropertyName("calendarId") String calendarId, @JsonRpcContent com.google.api.gwt.services.calendar.shared.model.Calendar content);

    /**
     * Request object to call the "calendar.calendars.patch" method.
     */
    @JsonRpcWireName(value="calendar.calendars.patch", version="v3")
    public interface PatchRequest extends Request<com.google.api.gwt.services.calendar.shared.model.Calendar> {

      /** Calendar identifier. */
      @PropertyName("calendarId")
      PatchRequest setCalendarId(@PropertyName("calendarId") String calendarId);
    }
    /**
     * Deletes a secondary calendar.
     *
     *
     * @param calendarId Calendar identifier.
     */
    DeleteRequest delete(@PropertyName("calendarId") String calendarId);

    /**
     * Request object to call the "calendar.calendars.delete" method.
     */
    @JsonRpcWireName(value="calendar.calendars.delete", version="v3")
    public interface DeleteRequest extends Request<Void> {

      /** Calendar identifier. */
      @PropertyName("calendarId")
      DeleteRequest setCalendarId(@PropertyName("calendarId") String calendarId);
    }
  }
  /** Returns the {@link #AclContext} context. */
  AclContext acl();

  /**
   * The {@link RequestContext} used to call methods on the "acl" collection.
   */
  @JsonRpcService
  public interface AclContext extends RequestContext {

    /**
     * Creates an access control rule.
     *
     *
     * @param calendarId Calendar identifier.
     * @param content Request body content.
     */
    InsertRequest insert(@PropertyName("calendarId") String calendarId, @JsonRpcContent com.google.api.gwt.services.calendar.shared.model.AclRule content);

    /**
     * Request object to call the "calendar.acl.insert" method.
     */
    @JsonRpcWireName(value="calendar.acl.insert", version="v3")
    public interface InsertRequest extends Request<com.google.api.gwt.services.calendar.shared.model.AclRule> {

      /** Calendar identifier. */
      @PropertyName("calendarId")
      InsertRequest setCalendarId(@PropertyName("calendarId") String calendarId);
    }
    /**
     * Returns an access control rule.
     *
     *
     * @param calendarId Calendar identifier.
     * @param ruleId ACL rule identifier.
     */
    GetRequest get(@PropertyName("calendarId") String calendarId, @PropertyName("ruleId") String ruleId);

    /**
     * Request object to call the "calendar.acl.get" method.
     */
    @JsonRpcWireName(value="calendar.acl.get", version="v3")
    public interface GetRequest extends Request<com.google.api.gwt.services.calendar.shared.model.AclRule> {

      /** Calendar identifier. */
      @PropertyName("calendarId")
      GetRequest setCalendarId(@PropertyName("calendarId") String calendarId);

      /** ACL rule identifier. */
      @PropertyName("ruleId")
      GetRequest setRuleId(@PropertyName("ruleId") String ruleId);
    }
    /**
     * Returns the rules in the access control list for the calendar.
     *
     *
     * @param calendarId Calendar identifier.
     */
    ListRequest list(@PropertyName("calendarId") String calendarId);

    /**
     * Request object to call the "calendar.acl.list" method.
     */
    @JsonRpcWireName(value="calendar.acl.list", version="v3")
    public interface ListRequest extends Request<com.google.api.gwt.services.calendar.shared.model.Acl> {

      /** Calendar identifier. */
      @PropertyName("calendarId")
      ListRequest setCalendarId(@PropertyName("calendarId") String calendarId);
    }
    /**
     * Updates an access control rule.
     *
     *
     * @param calendarId Calendar identifier.
     * @param ruleId ACL rule identifier.
     * @param content Request body content.
     */
    UpdateRequest update(@PropertyName("calendarId") String calendarId, @PropertyName("ruleId") String ruleId, @JsonRpcContent com.google.api.gwt.services.calendar.shared.model.AclRule content);

    /**
     * Request object to call the "calendar.acl.update" method.
     */
    @JsonRpcWireName(value="calendar.acl.update", version="v3")
    public interface UpdateRequest extends Request<com.google.api.gwt.services.calendar.shared.model.AclRule> {

      /** Calendar identifier. */
      @PropertyName("calendarId")
      UpdateRequest setCalendarId(@PropertyName("calendarId") String calendarId);

      /** ACL rule identifier. */
      @PropertyName("ruleId")
      UpdateRequest setRuleId(@PropertyName("ruleId") String ruleId);
    }
    /**
     * Updates an access control rule. This method supports patch semantics.
     *
     *
     * @param calendarId Calendar identifier.
     * @param ruleId ACL rule identifier.
     * @param content Request body content.
     */
    PatchRequest patch(@PropertyName("calendarId") String calendarId, @PropertyName("ruleId") String ruleId, @JsonRpcContent com.google.api.gwt.services.calendar.shared.model.AclRule content);

    /**
     * Request object to call the "calendar.acl.patch" method.
     */
    @JsonRpcWireName(value="calendar.acl.patch", version="v3")
    public interface PatchRequest extends Request<com.google.api.gwt.services.calendar.shared.model.AclRule> {

      /** Calendar identifier. */
      @PropertyName("calendarId")
      PatchRequest setCalendarId(@PropertyName("calendarId") String calendarId);

      /** ACL rule identifier. */
      @PropertyName("ruleId")
      PatchRequest setRuleId(@PropertyName("ruleId") String ruleId);
    }
    /**
     * Deletes an access control rule.
     *
     *
     * @param calendarId Calendar identifier.
     * @param ruleId ACL rule identifier.
     */
    DeleteRequest delete(@PropertyName("calendarId") String calendarId, @PropertyName("ruleId") String ruleId);

    /**
     * Request object to call the "calendar.acl.delete" method.
     */
    @JsonRpcWireName(value="calendar.acl.delete", version="v3")
    public interface DeleteRequest extends Request<Void> {

      /** Calendar identifier. */
      @PropertyName("calendarId")
      DeleteRequest setCalendarId(@PropertyName("calendarId") String calendarId);

      /** ACL rule identifier. */
      @PropertyName("ruleId")
      DeleteRequest setRuleId(@PropertyName("ruleId") String ruleId);
    }
  }
  /** Returns the {@link #ColorsContext} context. */
  ColorsContext colors();

  /**
   * The {@link RequestContext} used to call methods on the "colors" collection.
   */
  @JsonRpcService
  public interface ColorsContext extends RequestContext {

    /**
     * Returns the color definitions for calendars and events.
     *
     *
     */
    GetRequest get();

    /**
     * Request object to call the "calendar.colors.get" method.
     */
    @JsonRpcWireName(value="calendar.colors.get", version="v3")
    public interface GetRequest extends Request<com.google.api.gwt.services.calendar.shared.model.Colors> {
    }
  }
  /** Returns the {@link #EventsContext} context. */
  EventsContext events();

  /**
   * The {@link RequestContext} used to call methods on the "events" collection.
   */
  @JsonRpcService
  public interface EventsContext extends RequestContext {

    /**
     * Resets a specialized instance of a recurring event to its original state.
     *
     *
     * @param calendarId Calendar identifier.
     * @param eventId Event identifier.
     */
    ResetRequest reset(@PropertyName("calendarId") String calendarId, @PropertyName("eventId") String eventId);

    /**
     * Request object to call the "calendar.events.reset" method.
     */
    @JsonRpcWireName(value="calendar.events.reset", version="v3")
    public interface ResetRequest extends Request<com.google.api.gwt.services.calendar.shared.model.Event> {

      /** Calendar identifier. */
      @PropertyName("calendarId")
      ResetRequest setCalendarId(@PropertyName("calendarId") String calendarId);

      /** Event identifier. */
      @PropertyName("eventId")
      ResetRequest setEventId(@PropertyName("eventId") String eventId);

      /** Whether to send notifications about the event update. Optional. The default is False. */
      @PropertyName("sendNotifications")
      ResetRequest setSendNotifications(@PropertyName("sendNotifications") Boolean sendNotifications);
    }
    /**
     * Creates an event.
     *
     *
     * @param calendarId Calendar identifier.
     * @param content Request body content.
     */
    InsertRequest insert(@PropertyName("calendarId") String calendarId, @JsonRpcContent com.google.api.gwt.services.calendar.shared.model.Event content);

    /**
     * Request object to call the "calendar.events.insert" method.
     */
    @JsonRpcWireName(value="calendar.events.insert", version="v3")
    public interface InsertRequest extends Request<com.google.api.gwt.services.calendar.shared.model.Event> {

      /** Calendar identifier. */
      @PropertyName("calendarId")
      InsertRequest setCalendarId(@PropertyName("calendarId") String calendarId);

      /**
     * Whether to send notifications about the creation of the new event. Optional. The default is
     * False.
     */
      @PropertyName("sendNotifications")
      InsertRequest setSendNotifications(@PropertyName("sendNotifications") Boolean sendNotifications);
    }
    /**
     * Returns an event.
     *
     *
     * @param calendarId Calendar identifier.
     * @param eventId Event identifier.
     */
    GetRequest get(@PropertyName("calendarId") String calendarId, @PropertyName("eventId") String eventId);

    /**
     * Request object to call the "calendar.events.get" method.
     */
    @JsonRpcWireName(value="calendar.events.get", version="v3")
    public interface GetRequest extends Request<com.google.api.gwt.services.calendar.shared.model.Event> {

      /** Calendar identifier. */
      @PropertyName("calendarId")
      GetRequest setCalendarId(@PropertyName("calendarId") String calendarId);

      /** Event identifier. */
      @PropertyName("eventId")
      GetRequest setEventId(@PropertyName("eventId") String eventId);

      /** Time zone used in the response. Optional. The default is the time zone of the calendar. */
      @PropertyName("timeZone")
      GetRequest setTimeZone(@PropertyName("timeZone") String timeZone);

      /**
     * The maximum number of attendees to include in the response. If there are more than the
     * specified number of attendees, only the participant is returned. Optional.
     */
      @PropertyName("maxAttendees")
      GetRequest setMaxAttendees(@PropertyName("maxAttendees") Integer maxAttendees);
    }
    /**
     * Moves an event to another calendar, i.e. changes an event's organizer.
     *
     *
     * @param calendarId Calendar identifier of the source calendar where the event currently is on.
     * @param eventId Event identifier.
     * @param destination Calendar identifier of the target calendar where the event is to be moved to.
     */
    MoveRequest move(@PropertyName("calendarId") String calendarId, @PropertyName("eventId") String eventId, @PropertyName("destination") String destination);

    /**
     * Request object to call the "calendar.events.move" method.
     */
    @JsonRpcWireName(value="calendar.events.move", version="v3")
    public interface MoveRequest extends Request<com.google.api.gwt.services.calendar.shared.model.Event> {

      /** Calendar identifier of the source calendar where the event currently is on. */
      @PropertyName("calendarId")
      MoveRequest setCalendarId(@PropertyName("calendarId") String calendarId);

      /** Event identifier. */
      @PropertyName("eventId")
      MoveRequest setEventId(@PropertyName("eventId") String eventId);

      /** Calendar identifier of the target calendar where the event is to be moved to. */
      @PropertyName("destination")
      MoveRequest setDestination(@PropertyName("destination") String destination);

      /**
     * Whether to send notifications about the change of the event's organizer. Optional. The
     * default is False.
     */
      @PropertyName("sendNotifications")
      MoveRequest setSendNotifications(@PropertyName("sendNotifications") Boolean sendNotifications);
    }
    /**
     * Returns events on the specified calendar.
     *
     *
     * @param calendarId Calendar identifier.
     */
    ListRequest list(@PropertyName("calendarId") String calendarId);

    /**
     * Request object to call the "calendar.events.list" method.
     */
    @JsonRpcWireName(value="calendar.events.list", version="v3")
    public interface ListRequest extends Request<com.google.api.gwt.services.calendar.shared.model.Events> {

      /** Calendar identifier. */
      @PropertyName("calendarId")
      ListRequest setCalendarId(@PropertyName("calendarId") String calendarId);

      /**
     * The order of the events returned in the result. Optional. The default is an unspecified,
     * stable order.
     */
      @PropertyName("orderBy")
      ListRequest setOrderBy(@PropertyName("orderBy") ListRequest.OrderBy orderBy);

      /** Possible values for {@link #setOrderBy(OrderBy)}. */
      public enum OrderBy {

        /**
     * Order by the start date/time (ascending). This is only available when querying single events
     * (i.e. the parameter "singleEvents" is True)
     */
        @PropertyName("startTime") STARTTIME,
        /** Order by last modification time (ascending). */
        @PropertyName("updated") UPDATED,
        ;
      }
      /** Whether to include hidden invitations in the result. Optional. The default is False. */
      @PropertyName("showHiddenInvitations")
      ListRequest setShowHiddenInvitations(@PropertyName("showHiddenInvitations") Boolean showHiddenInvitations);

      /**
     * Whether to include deleted events (with 'eventStatus' equals 'cancelled') in the result.
     * Optional. The default is False.
     */
      @PropertyName("showDeleted")
      ListRequest setShowDeleted(@PropertyName("showDeleted") Boolean showDeleted);

      /** Specifies iCalendar UID (iCalUID) of events to be included in the response. Optional. */
      @PropertyName("iCalUID")
      ListRequest setICalUID(@PropertyName("iCalUID") String iCalUID);

      /**
     * Lower bound for an event's last modification time (as a RFC 3339 timestamp) to filter by.
     * Optional. The default is not to filter by last modification time.
     */
      @PropertyName("updatedMin")
      ListRequest setUpdatedMin(@PropertyName("updatedMin") String updatedMin);

      /**
     * Whether to expand recurring events into instances and only return single one-off events and
     * instances of recurring events, but not the underlying recurring events themselves. Optional.
     * The default is False.
     */
      @PropertyName("singleEvents")
      ListRequest setSingleEvents(@PropertyName("singleEvents") Boolean singleEvents);

      /** Maximum number of events returned on one result page. Optional. */
      @PropertyName("maxResults")
      ListRequest setMaxResults(@PropertyName("maxResults") Integer maxResults);

      /**
     * Free text search terms to find events that match these terms in any field, except for
     * extended properties. Optional.
     */
      @PropertyName("q")
      ListRequest setQ(@PropertyName("q") String q);

      /** Token specifying which result page to return. Optional. */
      @PropertyName("pageToken")
      ListRequest setPageToken(@PropertyName("pageToken") String pageToken);

      /**
     * Lower bound (inclusive) for an event's end time to filter by. Optional. The default is not to
     * filter by end time.
     */
      @PropertyName("timeMin")
      ListRequest setTimeMin(@PropertyName("timeMin") String timeMin);

      /** Time zone used in the response. Optional. The default is the time zone of the calendar. */
      @PropertyName("timeZone")
      ListRequest setTimeZone(@PropertyName("timeZone") String timeZone);

      /**
     * Upper bound (exclusive) for an event's start time to filter by. Optional. The default is not
     * to filter by start time.
     */
      @PropertyName("timeMax")
      ListRequest setTimeMax(@PropertyName("timeMax") String timeMax);

      /**
     * The maximum number of attendees to include in the response. If there are more than the
     * specified number of attendees, only the participant is returned. Optional.
     */
      @PropertyName("maxAttendees")
      ListRequest setMaxAttendees(@PropertyName("maxAttendees") Integer maxAttendees);
    }
    /**
     * Updates an event.
     *
     *
     * @param calendarId Calendar identifier.
     * @param eventId Event identifier.
     * @param content Request body content.
     */
    UpdateRequest update(@PropertyName("calendarId") String calendarId, @PropertyName("eventId") String eventId, @JsonRpcContent com.google.api.gwt.services.calendar.shared.model.Event content);

    /**
     * Request object to call the "calendar.events.update" method.
     */
    @JsonRpcWireName(value="calendar.events.update", version="v3")
    public interface UpdateRequest extends Request<com.google.api.gwt.services.calendar.shared.model.Event> {

      /** Calendar identifier. */
      @PropertyName("calendarId")
      UpdateRequest setCalendarId(@PropertyName("calendarId") String calendarId);

      /** Event identifier. */
      @PropertyName("eventId")
      UpdateRequest setEventId(@PropertyName("eventId") String eventId);

      /**
     * Whether to send notifications about the event update (e.g. attendee's responses, title
     * changes, etc.). Optional. The default is False.
     */
      @PropertyName("sendNotifications")
      UpdateRequest setSendNotifications(@PropertyName("sendNotifications") Boolean sendNotifications);
    }
    /**
     * Updates an event. This method supports patch semantics.
     *
     *
     * @param calendarId Calendar identifier.
     * @param eventId Event identifier.
     * @param content Request body content.
     */
    PatchRequest patch(@PropertyName("calendarId") String calendarId, @PropertyName("eventId") String eventId, @JsonRpcContent com.google.api.gwt.services.calendar.shared.model.Event content);

    /**
     * Request object to call the "calendar.events.patch" method.
     */
    @JsonRpcWireName(value="calendar.events.patch", version="v3")
    public interface PatchRequest extends Request<com.google.api.gwt.services.calendar.shared.model.Event> {

      /** Calendar identifier. */
      @PropertyName("calendarId")
      PatchRequest setCalendarId(@PropertyName("calendarId") String calendarId);

      /** Event identifier. */
      @PropertyName("eventId")
      PatchRequest setEventId(@PropertyName("eventId") String eventId);

      /**
     * Whether to send notifications about the event update (e.g. attendee's responses, title
     * changes, etc.). Optional. The default is False.
     */
      @PropertyName("sendNotifications")
      PatchRequest setSendNotifications(@PropertyName("sendNotifications") Boolean sendNotifications);
    }
    /**
     * Returns instances of the specified recurring event.
     *
     *
     * @param calendarId Calendar identifier.
     * @param eventId Recurring event identifier.
     */
    InstancesRequest instances(@PropertyName("calendarId") String calendarId, @PropertyName("eventId") String eventId);

    /**
     * Request object to call the "calendar.events.instances" method.
     */
    @JsonRpcWireName(value="calendar.events.instances", version="v3")
    public interface InstancesRequest extends Request<com.google.api.gwt.services.calendar.shared.model.Events> {

      /** Calendar identifier. */
      @PropertyName("calendarId")
      InstancesRequest setCalendarId(@PropertyName("calendarId") String calendarId);

      /** Recurring event identifier. */
      @PropertyName("eventId")
      InstancesRequest setEventId(@PropertyName("eventId") String eventId);

      /**
     * Whether to include deleted events (with 'eventStatus' equals 'cancelled') in the result.
     * Optional. The default is False.
     */
      @PropertyName("showDeleted")
      InstancesRequest setShowDeleted(@PropertyName("showDeleted") Boolean showDeleted);

      /** Maximum number of events returned on one result page. Optional. */
      @PropertyName("maxResults")
      InstancesRequest setMaxResults(@PropertyName("maxResults") Integer maxResults);

      /** Token specifying which result page to return. Optional. */
      @PropertyName("pageToken")
      InstancesRequest setPageToken(@PropertyName("pageToken") String pageToken);

      /** Time zone used in the response. Optional. The default is the time zone of the calendar. */
      @PropertyName("timeZone")
      InstancesRequest setTimeZone(@PropertyName("timeZone") String timeZone);

      /** The original start time of the instance in the result. Optional. */
      @PropertyName("originalStart")
      InstancesRequest setOriginalStart(@PropertyName("originalStart") String originalStart);

      /**
     * The maximum number of attendees to include in the response. If there are more than the
     * specified number of attendees, only the participant is returned. Optional.
     */
      @PropertyName("maxAttendees")
      InstancesRequest setMaxAttendees(@PropertyName("maxAttendees") Integer maxAttendees);
    }
    /**
     * Imports an event.
     *
     *
     * @param calendarId Calendar identifier.
     * @param content Request body content.
     */
    CalendarImportRequest calendarImport(@PropertyName("calendarId") String calendarId, @JsonRpcContent com.google.api.gwt.services.calendar.shared.model.Event content);

    /**
     * Request object to call the "calendar.events.import" method.
     */
    @JsonRpcWireName(value="calendar.events.import", version="v3")
    public interface CalendarImportRequest extends Request<com.google.api.gwt.services.calendar.shared.model.Event> {

      /** Calendar identifier. */
      @PropertyName("calendarId")
      CalendarImportRequest setCalendarId(@PropertyName("calendarId") String calendarId);
    }
    /**
     * Creates an event based on a simple text string.
     *
     *
     * @param calendarId Calendar identifier.
     * @param text The text describing the event to be created.
     */
    QuickAddRequest quickAdd(@PropertyName("calendarId") String calendarId, @PropertyName("text") String text);

    /**
     * Request object to call the "calendar.events.quickAdd" method.
     */
    @JsonRpcWireName(value="calendar.events.quickAdd", version="v3")
    public interface QuickAddRequest extends Request<com.google.api.gwt.services.calendar.shared.model.Event> {

      /** Calendar identifier. */
      @PropertyName("calendarId")
      QuickAddRequest setCalendarId(@PropertyName("calendarId") String calendarId);

      /** The text describing the event to be created. */
      @PropertyName("text")
      QuickAddRequest setText(@PropertyName("text") String text);

      /**
     * Whether to send notifications about the creation of the event. Optional. The default is
     * False.
     */
      @PropertyName("sendNotifications")
      QuickAddRequest setSendNotifications(@PropertyName("sendNotifications") Boolean sendNotifications);
    }
    /**
     * Deletes an event.
     *
     *
     * @param calendarId Calendar identifier.
     * @param eventId Event identifier.
     */
    DeleteRequest delete(@PropertyName("calendarId") String calendarId, @PropertyName("eventId") String eventId);

    /**
     * Request object to call the "calendar.events.delete" method.
     */
    @JsonRpcWireName(value="calendar.events.delete", version="v3")
    public interface DeleteRequest extends Request<Void> {

      /** Calendar identifier. */
      @PropertyName("calendarId")
      DeleteRequest setCalendarId(@PropertyName("calendarId") String calendarId);

      /** Event identifier. */
      @PropertyName("eventId")
      DeleteRequest setEventId(@PropertyName("eventId") String eventId);

      /**
     * Whether to send notifications about the deletion of the event. Optional. The default is
     * False.
     */
      @PropertyName("sendNotifications")
      DeleteRequest setSendNotifications(@PropertyName("sendNotifications") Boolean sendNotifications);
    }
  }


}
