/*
 * Copyright (c) 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.
 */

package com.google.api.gwt.services.calendar.shared.model;


import com.google.web.bindery.autobean.shared.AutoBean.PropertyName;
import com.google.web.bindery.autobean.shared.Splittable;
import com.google.web.bindery.requestfactory.shared.JsonRpcProxy;
import com.google.web.bindery.requestfactory.shared.ValueProxy;


/**
 * Model definition for Calendar.Event.
 *
 * This class models an object which will be transmitted to or from the Calendar service.
 *
 * @author Google, Inc.
 */
@JsonRpcProxy
public interface Event extends ValueProxy {

  /** The creator of the event. Read-only. */
  @PropertyName("creator")
  EventCreator getCreator();

  @PropertyName("creator")
  void setCreator(EventCreator creator);

  /**
 * The organizer of the event. If the organizer is also an attendee, this is indicated with a
 * separate entry in 'attendees' with the 'organizer' field set to True.
 */
  @PropertyName("organizer")
  EventOrganizer getOrganizer();

  @PropertyName("organizer")
  void setOrganizer(EventOrganizer organizer);

  /** Identifier of the event. */
  @PropertyName("id")
  String getId();

  @PropertyName("id")
  void setId(String id);

  /** The attendees of the event. */
  @PropertyName("attendees")
  java.util.List<EventAttendee> getAttendees();

  @PropertyName("attendees")
  void setAttendees(java.util.List<EventAttendee> attendees);

  /** An absolute link to this event in the Google Calendar Web UI. Read-only. */
  @PropertyName("htmlLink")
  String getHtmlLink();

  @PropertyName("htmlLink")
  void setHtmlLink(String htmlLink);

  /**
 * List of RRULE, EXRULE, RDATE and EXDATE lines for a recurring event. This field is omitted for
 * single events or instances of recurring events.
 */
  @PropertyName("recurrence")
  java.util.List<String> getRecurrence();

  @PropertyName("recurrence")
  void setRecurrence(java.util.List<String> recurrence);

  /**
 * The start time of the event. For a recurring event, this is the start time of the first instance.
 */
  @PropertyName("start")
  EventDateTime getStart();

  @PropertyName("start")
  void setStart(EventDateTime start);

  /** ETag of the resource. */
  @PropertyName("etag")
  String getEtag();

  @PropertyName("etag")
  void setEtag(String etag);

  /** Geographic location of the event as free-form text. Optional. */
  @PropertyName("location")
  String getLocation();

  @PropertyName("location")
  void setLocation(String location);

  /**
 * For an instance of a recurring event, this is the event ID of the recurring event itself.
 * Immutable.
 */
  @PropertyName("recurringEventId")
  String getRecurringEventId();

  @PropertyName("recurringEventId")
  void setRecurringEventId(String recurringEventId);

  /**
 * For an instance of a recurring event, this is the time at which this event would start according
 * to the recurrence data in the recurring event identified by recurringEventId. Immutable.
 */
  @PropertyName("originalStartTime")
  EventDateTime getOriginalStartTime();

  @PropertyName("originalStartTime")
  void setOriginalStartTime(EventDateTime originalStartTime);

  /**
 * Status of the event. Optional. Possible values are: - "confirmed" - The event is confirmed. This
 * is the default status. - "tentative" - The event is tentatively confirmed. - "cancelled" - The
 * event is cancelled.
 */
  @PropertyName("status")
  String getStatus();

  @PropertyName("status")
  void setStatus(String status);

  /** Last modification time of the event (as a RFC 3339 timestamp). Read-only. */
  @PropertyName("updated")
  String getUpdated();

  @PropertyName("updated")
  void setUpdated(String updated);

  /** A gadget that extends this event. */
  @PropertyName("gadget")
  EventGadget getGadget();

  @PropertyName("gadget")
  void setGadget(EventGadget gadget);

  /** Description of the event. Optional. */
  @PropertyName("description")
  String getDescription();

  @PropertyName("description")
  void setDescription(String description);

  /** Event ID in the iCalendar format. */
  @PropertyName("iCalUID")
  String getICalUID();

  @PropertyName("iCalUID")
  void setICalUID(String iCalUID);

  /** Extended properties of the event. */
  @PropertyName("extendedProperties")
  EventExtendedProperties getExtendedProperties();

  @PropertyName("extendedProperties")
  void setExtendedProperties(EventExtendedProperties extendedProperties);

  /** Sequence number as per iCalendar. */
  @PropertyName("sequence")
  Integer getSequence();

  @PropertyName("sequence")
  void setSequence(Integer sequence);

  /**
 * Visibility of the event. Optional. Possible values are: - "default" - Uses the default visibility
 * for events on the calendar. This is the default value. - "public" - The event is public and event
 * details are visible to all readers of the calendar. - "private" - The event is private and only
 * event attendees may view event details. - "confidential" - The event is private. This value is
 * provided for compatibility reasons.
 */
  @PropertyName("visibility")
  String getVisibility();

  @PropertyName("visibility")
  void setVisibility(String visibility);

  /**
 * Whether attendees other than the organizer can modify the event. Optional. The default is False.
 */
  @PropertyName("guestsCanModify")
  Boolean getGuestsCanModify();

  @PropertyName("guestsCanModify")
  void setGuestsCanModify(Boolean guestsCanModify);

  /**
 * The end time of the event. For a recurring event, this is the end time of the first instance.
 */
  @PropertyName("end")
  EventDateTime getEnd();

  @PropertyName("end")
  void setEnd(EventDateTime end);

  /**
 * Whether attendees have been omitted from the event's representation. When retrieving an event,
 * this is due to a restriction specified by the 'maxAttendee' query parameter. When updating an
 * event, this can be used to only update the participant's response. Optional. The default is
 * False.
 */
  @PropertyName("attendeesOmitted")
  Boolean getAttendeesOmitted();

  @PropertyName("attendeesOmitted")
  void setAttendeesOmitted(Boolean attendeesOmitted);

  /** Type of the resource ("calendar#event"). */
  @PropertyName("kind")
  String getKind();

  @PropertyName("kind")
  void setKind(String kind);

  /** Creation time of the event (as a RFC 3339 timestamp). Read-only. */
  @PropertyName("created")
  String getCreated();

  @PropertyName("created")
  void setCreated(String created);

  /**
 * The color of the event. This is an ID referring to an entry in the "event" section of the colors
 * definition (see the "colors" endpoint). Optional.
 */
  @PropertyName("colorId")
  String getColorId();

  @PropertyName("colorId")
  void setColorId(String colorId);

  /** Whether anyone can invite themselves to the event. Optional. The default is False. */
  @PropertyName("anyoneCanAddSelf")
  Boolean getAnyoneCanAddSelf();

  @PropertyName("anyoneCanAddSelf")
  void setAnyoneCanAddSelf(Boolean anyoneCanAddSelf);

  /** Information about the event's reminders for the authenticated user. */
  @PropertyName("reminders")
  EventReminders getReminders();

  @PropertyName("reminders")
  void setReminders(EventReminders reminders);

  /**
 * Whether attendees other than the organizer can see who the event's attendees are. Optional. The
 * default is False.
 */
  @PropertyName("guestsCanSeeOtherGuests")
  Boolean getGuestsCanSeeOtherGuests();

  @PropertyName("guestsCanSeeOtherGuests")
  void setGuestsCanSeeOtherGuests(Boolean guestsCanSeeOtherGuests);

  /** Title of the event. */
  @PropertyName("summary")
  String getSummary();

  @PropertyName("summary")
  void setSummary(String summary);

  /**
 * Whether attendees other than the organizer can invite others to the event. Optional. The default
 * is False.
 */
  @PropertyName("guestsCanInviteOthers")
  Boolean getGuestsCanInviteOthers();

  @PropertyName("guestsCanInviteOthers")
  void setGuestsCanInviteOthers(Boolean guestsCanInviteOthers);

  /**
 * Whether the event blocks time on the calendar. Optional. Possible values are: - "opaque" - The
 * event blocks time on the calendar. This is the default value. - "transparent" - The event does
 * not block time on the calendar.
 */
  @PropertyName("transparency")
  String getTransparency();

  @PropertyName("transparency")
  void setTransparency(String transparency);

  /**
 * Whether this is a private event copy where changes are not shared with other copies on other
 * calendars. Optional. Immutable.
 */
  @PropertyName("privateCopy")
  Boolean getPrivateCopy();

  @PropertyName("privateCopy")
  void setPrivateCopy(Boolean privateCopy);
}
