/*
 * Copyright (c) 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.

 */

package com.google.api.gwt.services.plus.shared;

import com.google.api.gwt.services.plus.shared.model.*;
import com.google.api.gwt.shared.AuthScope;
import com.google.web.bindery.autobean.shared.AutoBean.PropertyName;
import com.google.web.bindery.autobean.shared.Splittable;
import com.google.web.bindery.requestfactory.shared.JsonRpcContent;
import com.google.web.bindery.requestfactory.shared.JsonRpcService;
import com.google.web.bindery.requestfactory.shared.JsonRpcWireName;
import com.google.web.bindery.requestfactory.shared.Request;
import com.google.web.bindery.requestfactory.shared.RequestContext;
import com.google.web.bindery.requestfactory.shared.RequestFactory;

import java.math.BigInteger;
import java.util.HashMap;
import java.util.Map;
import java.util.List;

/**
 * Service definition for Plus (v1).
 *
 * <p>
 * The Google+ API enables developers to build on top of the Google+ platform.
 * </p>
 *
 * <p>
 * For more information about this service, see the
 * <a href="http://developers.google.com/+/api/" target="_blank">API Documentation</a>
 * </p>
 *
 * @author Google, Inc.
 */
public interface Plus extends RequestFactory {
  /** Available authentiation scopes for use with this service. */
  public enum PlusAuthScope implements AuthScope {

    /** View your Google+ information */
    PLUS_ME("https://www.googleapis.com/auth/plus.me"),
    ;
    private final String scope;
    private PlusAuthScope(String scope) {
      this.scope = scope;
    }

    /** The String value of this scope. */
    @Override
    public String getScope() {
      return scope;
    }
  }

  /** Returns the {@link #ActivitiesContext} context. */
  ActivitiesContext activities();

  /**
   * The {@link RequestContext} used to call methods on the "activities" collection.
   */
  @JsonRpcService
  public interface ActivitiesContext extends RequestContext {

    /**
     * List all of the activities in the specified collection for a particular user.
     *
     *
     * @param userId The ID of the user to get activities for. The special value "me" can be used to indicate the authenticated user.
     * @param collection The collection of activities to list.
     */
    ListRequest list(@PropertyName("userId") String userId, @PropertyName("collection") ListRequest.Collection collection);

    /**
     * Request object to call the "plus.activities.list" method.
     */
    @JsonRpcWireName(value="plus.activities.list", version="v1")
    public interface ListRequest extends Request<com.google.api.gwt.services.plus.shared.model.ActivityFeed> {

      /**
     * The ID of the user to get activities for. The special value "me" can be used to indicate the
     * authenticated user.
     */
      @PropertyName("userId")
      ListRequest setUserId(@PropertyName("userId") String userId);

      /** The collection of activities to list. */
      @PropertyName("collection")
      ListRequest setCollection(@PropertyName("collection") ListRequest.Collection collection);

      /** Possible values for {@link #setCollection(Collection)}. */
      public enum Collection {

        /** All public activities created by the specified user. */
        @PropertyName("public") PUBLIC,
        ;
      }
      /**
     * The continuation token, used to page through large result sets. To get the next page of
     * results, set this parameter to the value of "nextPageToken" from the previous response.
     */
      @PropertyName("pageToken")
      ListRequest setPageToken(@PropertyName("pageToken") String pageToken);

      /**
     * The maximum number of activities to include in the response, used for paging. For any
     * response, the actual number returned may be less than the specified maxResults.
     */
      @PropertyName("maxResults")
      ListRequest setMaxResults(@PropertyName("maxResults") Long maxResults);
    }
    /**
     * Get an activity.
     *
     *
     * @param activityId The ID of the activity to get.
     */
    GetRequest get(@PropertyName("activityId") String activityId);

    /**
     * Request object to call the "plus.activities.get" method.
     */
    @JsonRpcWireName(value="plus.activities.get", version="v1")
    public interface GetRequest extends Request<com.google.api.gwt.services.plus.shared.model.Activity> {

      /** The ID of the activity to get. */
      @PropertyName("activityId")
      GetRequest setActivityId(@PropertyName("activityId") String activityId);
    }
  }
  /** Returns the {@link #PeopleContext} context. */
  PeopleContext people();

  /**
   * The {@link RequestContext} used to call methods on the "people" collection.
   */
  @JsonRpcService
  public interface PeopleContext extends RequestContext {

    /**
     * Get a person's profile.
     *
     *
     * @param userId The ID of the person to get the profile for. The special value "me" can be used to indicate the authenticated user.
     */
    GetRequest get(@PropertyName("userId") String userId);

    /**
     * Request object to call the "plus.people.get" method.
     */
    @JsonRpcWireName(value="plus.people.get", version="v1")
    public interface GetRequest extends Request<com.google.api.gwt.services.plus.shared.model.Person> {

      /**
     * The ID of the person to get the profile for. The special value "me" can be used to indicate
     * the authenticated user.
     */
      @PropertyName("userId")
      GetRequest setUserId(@PropertyName("userId") String userId);
    }
  }


}
