/*
 * Copyright (c) 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.

 */

package com.google.api.gwt.services.tasks.shared;

import com.google.api.gwt.services.tasks.shared.model.*;
import com.google.api.gwt.shared.AuthScope;
import com.google.web.bindery.autobean.shared.AutoBean.PropertyName;
import com.google.web.bindery.autobean.shared.Splittable;
import com.google.web.bindery.requestfactory.shared.JsonRpcContent;
import com.google.web.bindery.requestfactory.shared.JsonRpcService;
import com.google.web.bindery.requestfactory.shared.JsonRpcWireName;
import com.google.web.bindery.requestfactory.shared.Request;
import com.google.web.bindery.requestfactory.shared.RequestContext;
import com.google.web.bindery.requestfactory.shared.RequestFactory;

import java.math.BigInteger;
import java.util.HashMap;
import java.util.Map;
import java.util.List;

/**
 * Service definition for Tasks (v1).
 *
 * <p>
 * Lets you manage your tasks and task lists.
 * </p>
 *
 * <p>
 * For more information about this service, see the
 * <a href="http://code.google.com/apis/tasks/v1/using.html" target="_blank">API Documentation</a>
 * </p>
 *
 * @author Google, Inc.
 */
public interface Tasks extends RequestFactory {
  /** Available authentiation scopes for use with this service. */
  public enum TasksAuthScope implements AuthScope {

    /** Manage your tasks */
    TASKS("https://www.googleapis.com/auth/tasks"),

    /** View your tasks */
    TASKS_READONLY("https://www.googleapis.com/auth/tasks.readonly"),
    ;
    private final String scope;
    private TasksAuthScope(String scope) {
      this.scope = scope;
    }

    /** The String value of this scope. */
    @Override
    public String getScope() {
      return scope;
    }
  }

  /** Returns the {@link #TasksOperationsContext} context. */
  TasksOperationsContext tasks();

  /**
   * The {@link RequestContext} used to call methods on the "tasks" collection.
   */
  @JsonRpcService
  public interface TasksOperationsContext extends RequestContext {

    /**
     * Creates a new task on the specified task list.
     *
     *
     * @param tasklist Task list identifier.
     * @param content Request body content.
     */
    InsertRequest insert(@PropertyName("tasklist") String tasklist, @JsonRpcContent com.google.api.gwt.services.tasks.shared.model.Task content);

    /**
     * Request object to call the "tasks.tasks.insert" method.
     */
    @JsonRpcWireName(value="tasks.tasks.insert", version="v1")
    public interface InsertRequest extends Request<com.google.api.gwt.services.tasks.shared.model.Task> {

      /** Task list identifier. */
      @PropertyName("tasklist")
      InsertRequest setTasklist(@PropertyName("tasklist") String tasklist);

      /**
     * Parent task identifier. If the task is created at the top level, this parameter is omitted.
     * Optional.
     */
      @PropertyName("parent")
      InsertRequest setParent(@PropertyName("parent") String parent);

      /**
     * Previous sibling task identifier. If the task is created at the first position among its
     * siblings, this parameter is omitted. Optional.
     */
      @PropertyName("previous")
      InsertRequest setPrevious(@PropertyName("previous") String previous);
    }
    /**
     * Returns the specified task.
     *
     *
     * @param tasklist Task list identifier.
     * @param task Task identifier.
     */
    GetRequest get(@PropertyName("tasklist") String tasklist, @PropertyName("task") String task);

    /**
     * Request object to call the "tasks.tasks.get" method.
     */
    @JsonRpcWireName(value="tasks.tasks.get", version="v1")
    public interface GetRequest extends Request<com.google.api.gwt.services.tasks.shared.model.Task> {

      /** Task list identifier. */
      @PropertyName("tasklist")
      GetRequest setTasklist(@PropertyName("tasklist") String tasklist);

      /** Task identifier. */
      @PropertyName("task")
      GetRequest setTask(@PropertyName("task") String task);
    }
    /**
     * Clears all completed tasks from the specified task list. The affected tasks will be marked as
     * 'hidden' and no longer be returned by default when retrieving all tasks for a task list.
     *
     *
     * @param tasklist Task list identifier.
     */
    ClearRequest clear(@PropertyName("tasklist") String tasklist);

    /**
     * Request object to call the "tasks.tasks.clear" method.
     */
    @JsonRpcWireName(value="tasks.tasks.clear", version="v1")
    public interface ClearRequest extends Request<Void> {

      /** Task list identifier. */
      @PropertyName("tasklist")
      ClearRequest setTasklist(@PropertyName("tasklist") String tasklist);
    }
    /**
     * Moves the specified task to another position in the task list. This can include putting it as a
     * child task under a new parent and/or move it to a different position among its sibling tasks.
     *
     *
     * @param tasklist Task list identifier.
     * @param task Task identifier.
     */
    MoveRequest move(@PropertyName("tasklist") String tasklist, @PropertyName("task") String task);

    /**
     * Request object to call the "tasks.tasks.move" method.
     */
    @JsonRpcWireName(value="tasks.tasks.move", version="v1")
    public interface MoveRequest extends Request<com.google.api.gwt.services.tasks.shared.model.Task> {

      /** Task list identifier. */
      @PropertyName("tasklist")
      MoveRequest setTasklist(@PropertyName("tasklist") String tasklist);

      /** Task identifier. */
      @PropertyName("task")
      MoveRequest setTask(@PropertyName("task") String task);

      /**
     * New parent task identifier. If the task is moved to the top level, this parameter is omitted.
     * Optional.
     */
      @PropertyName("parent")
      MoveRequest setParent(@PropertyName("parent") String parent);

      /**
     * New previous sibling task identifier. If the task is moved to the first position among its
     * siblings, this parameter is omitted. Optional.
     */
      @PropertyName("previous")
      MoveRequest setPrevious(@PropertyName("previous") String previous);
    }
    /**
     * Returns all tasks in the specified task list.
     *
     *
     * @param tasklist Task list identifier.
     */
    ListRequest list(@PropertyName("tasklist") String tasklist);

    /**
     * Request object to call the "tasks.tasks.list" method.
     */
    @JsonRpcWireName(value="tasks.tasks.list", version="v1")
    public interface ListRequest extends Request<com.google.api.gwt.services.tasks.shared.model.Tasks> {

      /** Task list identifier. */
      @PropertyName("tasklist")
      ListRequest setTasklist(@PropertyName("tasklist") String tasklist);

      /**
     * Upper bound for a task's due date (as a RFC 3339 timestamp) to filter by. Optional. The
     * default is not to filter by due date.
     */
      @PropertyName("dueMax")
      ListRequest setDueMax(@PropertyName("dueMax") String dueMax);

      /**
     * Flag indicating whether deleted tasks are returned in the result. Optional. The default is
     * False.
     */
      @PropertyName("showDeleted")
      ListRequest setShowDeleted(@PropertyName("showDeleted") Boolean showDeleted);

      /**
     * Lower bound for a task's last modification time (as a RFC 3339 timestamp) to filter by.
     * Optional. The default is not to filter by last modification time.
     */
      @PropertyName("updatedMin")
      ListRequest setUpdatedMin(@PropertyName("updatedMin") String updatedMin);

      /**
     * Lower bound for a task's completion date (as a RFC 3339 timestamp) to filter by. Optional.
     * The default is not to filter by completion date.
     */
      @PropertyName("completedMin")
      ListRequest setCompletedMin(@PropertyName("completedMin") String completedMin);

      /** Maximum number of task lists returned on one page. Optional. The default is 100. */
      @PropertyName("maxResults")
      ListRequest setMaxResults(@PropertyName("maxResults") Long maxResults);

      /**
     * Flag indicating whether completed tasks are returned in the result. Optional. The default is
     * True.
     */
      @PropertyName("showCompleted")
      ListRequest setShowCompleted(@PropertyName("showCompleted") Boolean showCompleted);

      /** Token specifying the result page to return. Optional. */
      @PropertyName("pageToken")
      ListRequest setPageToken(@PropertyName("pageToken") String pageToken);

      /**
     * Upper bound for a task's completion date (as a RFC 3339 timestamp) to filter by. Optional.
     * The default is not to filter by completion date.
     */
      @PropertyName("completedMax")
      ListRequest setCompletedMax(@PropertyName("completedMax") String completedMax);

      /**
     * Flag indicating whether hidden tasks are returned in the result. Optional. The default is
     * False.
     */
      @PropertyName("showHidden")
      ListRequest setShowHidden(@PropertyName("showHidden") Boolean showHidden);

      /**
     * Lower bound for a task's due date (as a RFC 3339 timestamp) to filter by. Optional. The
     * default is not to filter by due date.
     */
      @PropertyName("dueMin")
      ListRequest setDueMin(@PropertyName("dueMin") String dueMin);
    }
    /**
     * Updates the specified task.
     *
     *
     * @param tasklist Task list identifier.
     * @param task Task identifier.
     * @param content Request body content.
     */
    UpdateRequest update(@PropertyName("tasklist") String tasklist, @PropertyName("task") String task, @JsonRpcContent com.google.api.gwt.services.tasks.shared.model.Task content);

    /**
     * Request object to call the "tasks.tasks.update" method.
     */
    @JsonRpcWireName(value="tasks.tasks.update", version="v1")
    public interface UpdateRequest extends Request<com.google.api.gwt.services.tasks.shared.model.Task> {

      /** Task list identifier. */
      @PropertyName("tasklist")
      UpdateRequest setTasklist(@PropertyName("tasklist") String tasklist);

      /** Task identifier. */
      @PropertyName("task")
      UpdateRequest setTask(@PropertyName("task") String task);
    }
    /**
     * Updates the specified task. This method supports patch semantics.
     *
     *
     * @param tasklist Task list identifier.
     * @param task Task identifier.
     * @param content Request body content.
     */
    PatchRequest patch(@PropertyName("tasklist") String tasklist, @PropertyName("task") String task, @JsonRpcContent com.google.api.gwt.services.tasks.shared.model.Task content);

    /**
     * Request object to call the "tasks.tasks.patch" method.
     */
    @JsonRpcWireName(value="tasks.tasks.patch", version="v1")
    public interface PatchRequest extends Request<com.google.api.gwt.services.tasks.shared.model.Task> {

      /** Task list identifier. */
      @PropertyName("tasklist")
      PatchRequest setTasklist(@PropertyName("tasklist") String tasklist);

      /** Task identifier. */
      @PropertyName("task")
      PatchRequest setTask(@PropertyName("task") String task);
    }
    /**
     * Deletes the specified task from the task list.
     *
     *
     * @param tasklist Task list identifier.
     * @param task Task identifier.
     */
    DeleteRequest delete(@PropertyName("tasklist") String tasklist, @PropertyName("task") String task);

    /**
     * Request object to call the "tasks.tasks.delete" method.
     */
    @JsonRpcWireName(value="tasks.tasks.delete", version="v1")
    public interface DeleteRequest extends Request<Void> {

      /** Task list identifier. */
      @PropertyName("tasklist")
      DeleteRequest setTasklist(@PropertyName("tasklist") String tasklist);

      /** Task identifier. */
      @PropertyName("task")
      DeleteRequest setTask(@PropertyName("task") String task);
    }
  }
  /** Returns the {@link #TasklistsContext} context. */
  TasklistsContext tasklists();

  /**
   * The {@link RequestContext} used to call methods on the "tasklists" collection.
   */
  @JsonRpcService
  public interface TasklistsContext extends RequestContext {

    /**
     * Creates a new task list and adds it to the authenticated user's task lists.
     *
     *
     * @param content Request body content.
     */
    InsertRequest insert(@JsonRpcContent com.google.api.gwt.services.tasks.shared.model.TaskList content);

    /**
     * Request object to call the "tasks.tasklists.insert" method.
     */
    @JsonRpcWireName(value="tasks.tasklists.insert", version="v1")
    public interface InsertRequest extends Request<com.google.api.gwt.services.tasks.shared.model.TaskList> {
    }
    /**
     * Returns the authenticated user's specified task list.
     *
     *
     * @param tasklist Task list identifier.
     */
    GetRequest get(@PropertyName("tasklist") String tasklist);

    /**
     * Request object to call the "tasks.tasklists.get" method.
     */
    @JsonRpcWireName(value="tasks.tasklists.get", version="v1")
    public interface GetRequest extends Request<com.google.api.gwt.services.tasks.shared.model.TaskList> {

      /** Task list identifier. */
      @PropertyName("tasklist")
      GetRequest setTasklist(@PropertyName("tasklist") String tasklist);
    }
    /**
     * Returns all the authenticated user's task lists.
     *
     *
     */
    ListRequest list();

    /**
     * Request object to call the "tasks.tasklists.list" method.
     */
    @JsonRpcWireName(value="tasks.tasklists.list", version="v1")
    public interface ListRequest extends Request<com.google.api.gwt.services.tasks.shared.model.TaskLists> {

      /** Token specifying the result page to return. Optional. */
      @PropertyName("pageToken")
      ListRequest setPageToken(@PropertyName("pageToken") String pageToken);

      /** Maximum number of task lists returned on one page. Optional. The default is 100. */
      @PropertyName("maxResults")
      ListRequest setMaxResults(@PropertyName("maxResults") Long maxResults);
    }
    /**
     * Updates the authenticated user's specified task list.
     *
     *
     * @param tasklist Task list identifier.
     * @param content Request body content.
     */
    UpdateRequest update(@PropertyName("tasklist") String tasklist, @JsonRpcContent com.google.api.gwt.services.tasks.shared.model.TaskList content);

    /**
     * Request object to call the "tasks.tasklists.update" method.
     */
    @JsonRpcWireName(value="tasks.tasklists.update", version="v1")
    public interface UpdateRequest extends Request<com.google.api.gwt.services.tasks.shared.model.TaskList> {

      /** Task list identifier. */
      @PropertyName("tasklist")
      UpdateRequest setTasklist(@PropertyName("tasklist") String tasklist);
    }
    /**
     * Updates the authenticated user's specified task list. This method supports patch semantics.
     *
     *
     * @param tasklist Task list identifier.
     * @param content Request body content.
     */
    PatchRequest patch(@PropertyName("tasklist") String tasklist, @JsonRpcContent com.google.api.gwt.services.tasks.shared.model.TaskList content);

    /**
     * Request object to call the "tasks.tasklists.patch" method.
     */
    @JsonRpcWireName(value="tasks.tasklists.patch", version="v1")
    public interface PatchRequest extends Request<com.google.api.gwt.services.tasks.shared.model.TaskList> {

      /** Task list identifier. */
      @PropertyName("tasklist")
      PatchRequest setTasklist(@PropertyName("tasklist") String tasklist);
    }
    /**
     * Deletes the authenticated user's specified task list.
     *
     *
     * @param tasklist Task list identifier.
     */
    DeleteRequest delete(@PropertyName("tasklist") String tasklist);

    /**
     * Request object to call the "tasks.tasklists.delete" method.
     */
    @JsonRpcWireName(value="tasks.tasklists.delete", version="v1")
    public interface DeleteRequest extends Request<Void> {

      /** Task list identifier. */
      @PropertyName("tasklist")
      DeleteRequest setTasklist(@PropertyName("tasklist") String tasklist);
    }
  }


}
