/*
 * Copyright (c) 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.

 */

package com.google.api.gwt.services.urlshortener.shared;

import com.google.api.gwt.services.urlshortener.shared.model.*;
import com.google.api.gwt.shared.AuthScope;
import com.google.web.bindery.autobean.shared.AutoBean.PropertyName;
import com.google.web.bindery.autobean.shared.Splittable;
import com.google.web.bindery.requestfactory.shared.JsonRpcContent;
import com.google.web.bindery.requestfactory.shared.JsonRpcService;
import com.google.web.bindery.requestfactory.shared.JsonRpcWireName;
import com.google.web.bindery.requestfactory.shared.Request;
import com.google.web.bindery.requestfactory.shared.RequestContext;
import com.google.web.bindery.requestfactory.shared.RequestFactory;

import java.math.BigInteger;
import java.util.HashMap;
import java.util.Map;
import java.util.List;

/**
 * Service definition for Urlshortener (v1).
 *
 * <p>
 * Lets you create, inspect, and manage goo.gl short URLs
 * </p>
 *
 * <p>
 * For more information about this service, see the
 * <a href="http://code.google.com/apis/urlshortener/v1/getting_started.html" target="_blank">API Documentation</a>
 * </p>
 *
 * @author Google, Inc.
 */
public interface Urlshortener extends RequestFactory {
  /** Available authentiation scopes for use with this service. */
  public enum UrlshortenerAuthScope implements AuthScope {

    /** Manage your goo.gl short URLs */
    URLSHORTENER("https://www.googleapis.com/auth/urlshortener"),
    ;
    private final String scope;
    private UrlshortenerAuthScope(String scope) {
      this.scope = scope;
    }

    /** The String value of this scope. */
    @Override
    public String getScope() {
      return scope;
    }
  }

  /** Returns the {@link #UrlContext} context. */
  UrlContext url();

  /**
   * The {@link RequestContext} used to call methods on the "url" collection.
   */
  @JsonRpcService
  public interface UrlContext extends RequestContext {

    /**
     * Creates a new short URL.
     *
     *
     * @param content Request body content.
     */
    InsertRequest insert(@JsonRpcContent com.google.api.gwt.services.urlshortener.shared.model.Url content);

    /**
     * Request object to call the "urlshortener.url.insert" method.
     */
    @JsonRpcWireName(value="urlshortener.url.insert", version="v1")
    public interface InsertRequest extends Request<com.google.api.gwt.services.urlshortener.shared.model.Url> {
    }
    /**
     * Retrieves a list of URLs shortened by a user.
     *
     *
     */
    ListRequest list();

    /**
     * Request object to call the "urlshortener.url.list" method.
     */
    @JsonRpcWireName(value="urlshortener.url.list", version="v1")
    public interface ListRequest extends Request<com.google.api.gwt.services.urlshortener.shared.model.UrlHistory> {

      /** Token for requesting successive pages of results. */
      @PropertyName("start-token")
      ListRequest setStartToken(@PropertyName("start-token") String startToken);

      /** Additional information to return. */
      @PropertyName("projection")
      ListRequest setProjection(@PropertyName("projection") ListRequest.Projection projection);

      /** Possible values for {@link #setProjection(Projection)}. */
      public enum Projection {

        /** Returns short URL click counts. */
        @PropertyName("ANALYTICS_CLICKS") ANALYTICS_CLICKS,
        /** Returns short URL click counts. */
        @PropertyName("FULL") FULL,
        ;
      }}
    /**
     * Expands a short URL or gets creation time and analytics.
     *
     *
     * @param shortUrl The short URL, including the protocol.
     */
    GetRequest get(@PropertyName("shortUrl") String shortUrl);

    /**
     * Request object to call the "urlshortener.url.get" method.
     */
    @JsonRpcWireName(value="urlshortener.url.get", version="v1")
    public interface GetRequest extends Request<com.google.api.gwt.services.urlshortener.shared.model.Url> {

      /** The short URL, including the protocol. */
      @PropertyName("shortUrl")
      GetRequest setShortUrl(@PropertyName("shortUrl") String shortUrl);

      /** Additional information to return. */
      @PropertyName("projection")
      GetRequest setProjection(@PropertyName("projection") GetRequest.Projection projection);

      /** Possible values for {@link #setProjection(Projection)}. */
      public enum Projection {

        /** Returns only click counts. */
        @PropertyName("ANALYTICS_CLICKS") ANALYTICS_CLICKS,
        /** Returns only top string counts. */
        @PropertyName("ANALYTICS_TOP_STRINGS") ANALYTICS_TOP_STRINGS,
        /** Returns the creation timestamp and all available analytics. */
        @PropertyName("FULL") FULL,
        ;
      }}
  }


}
